{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "a9087a51",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.599965Z",
     "iopub.status.busy": "2024-08-12T10:05:50.599808Z",
     "iopub.status.idle": "2024-08-12T10:05:50.938605Z",
     "shell.execute_reply": "2024-08-12T10:05:50.938028Z"
    }
   },
   "outputs": [],
   "source": [
    "import sympy as sm\n",
    "import sympy.physics.mechanics as me\n",
    "me.init_vprinting(use_latex='mathjax')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "d4513646",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.940721Z",
     "iopub.status.busy": "2024-08-12T10:05:50.940516Z",
     "iopub.status.idle": "2024-08-12T10:05:50.944318Z",
     "shell.execute_reply": "2024-08-12T10:05:50.943888Z"
    }
   },
   "outputs": [],
   "source": [
    "class ReferenceFrame(me.ReferenceFrame):\n",
    "\n",
    "    def __init__(self, *args, **kwargs):\n",
    "\n",
    "        kwargs.pop('latexs', None)\n",
    "\n",
    "        lab = args[0].lower()\n",
    "        tex = r'\\hat{{{}}}_{}'\n",
    "\n",
    "        super(ReferenceFrame, self).__init__(*args,\n",
    "                                             latexs=(tex.format(lab, 'x'),\n",
    "                                                     tex.format(lab, 'y'),\n",
    "                                                     tex.format(lab, 'z')),\n",
    "                                             **kwargs)\n",
    "me.ReferenceFrame = ReferenceFrame"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "dc7def99",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.946077Z",
     "iopub.status.busy": "2024-08-12T10:05:50.945919Z",
     "iopub.status.idle": "2024-08-12T10:05:50.956306Z",
     "shell.execute_reply": "2024-08-12T10:05:50.955903Z"
    }
   },
   "outputs": [],
   "source": [
    "alpha, beta = me.dynamicsymbols('alpha, beta')\n",
    "\n",
    "N = me.ReferenceFrame('N')\n",
    "A = me.ReferenceFrame('A')\n",
    "B = me.ReferenceFrame('B')\n",
    "\n",
    "A.orient_axis(N, alpha, N.z)\n",
    "B.orient_axis(A, beta, A.x)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "9069ec1e",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.957915Z",
     "iopub.status.busy": "2024-08-12T10:05:50.957763Z",
     "iopub.status.idle": "2024-08-12T10:05:50.965389Z",
     "shell.execute_reply": "2024-08-12T10:05:50.964976Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle \\left( h\\hat{n}_z, \\  -  d\\hat{a}_x, \\  -  w\\hat{b}_x + (- c - \\frac{l}{2})\\hat{b}_z\\right)$"
      ],
      "text/plain": [
       "⎛h n_z, -d a_x,            ⎛     l⎞  ⎞\n",
       "⎜               -w b_x + ⎜-c - ─⎟ b_z⎟\n",
       "⎝                          ⎝     2⎠  ⎠"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "h, d, w, c, l = sm.symbols('h, d, w, c, l')\n",
    "\n",
    "r_O_P = h*N.z\n",
    "r_P_S = -d*A.x\n",
    "r_S_Q = -w*B.x - (c + l/2)*B.z\n",
    "\n",
    "r_O_P, r_P_S, r_S_Q"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "a93c41ea",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.966972Z",
     "iopub.status.busy": "2024-08-12T10:05:50.966815Z",
     "iopub.status.idle": "2024-08-12T10:05:50.972625Z",
     "shell.execute_reply": "2024-08-12T10:05:50.972230Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle 0$"
      ],
      "text/plain": [
       "0"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(r_O_P + r_P_S).dt(A)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "f6c69cb8",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.974168Z",
     "iopub.status.busy": "2024-08-12T10:05:50.974001Z",
     "iopub.status.idle": "2024-08-12T10:05:50.978105Z",
     "shell.execute_reply": "2024-08-12T10:05:50.977716Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle \\dot{\\alpha}\\hat{n}_z$"
      ],
      "text/plain": [
       "α̇ n_z"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "A.ang_vel_in(N)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "38997cc3",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.979667Z",
     "iopub.status.busy": "2024-08-12T10:05:50.979519Z",
     "iopub.status.idle": "2024-08-12T10:05:50.987185Z",
     "shell.execute_reply": "2024-08-12T10:05:50.986685Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "-d⋅α̇ a_y"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "me.cross(A.ang_vel_in(N), r_O_P + r_P_S)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "79d8a18f",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.988715Z",
     "iopub.status.busy": "2024-08-12T10:05:50.988555Z",
     "iopub.status.idle": "2024-08-12T10:05:50.998404Z",
     "shell.execute_reply": "2024-08-12T10:05:50.997987Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "-d⋅α̇ a_y"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "N_v_S = (r_O_P + r_P_S).dt(A) + me.cross(A.ang_vel_in(N), r_O_P + r_P_S)\n",
    "N_v_S"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "0642126f",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:50.999982Z",
     "iopub.status.busy": "2024-08-12T10:05:50.999833Z",
     "iopub.status.idle": "2024-08-12T10:05:51.005424Z",
     "shell.execute_reply": "2024-08-12T10:05:51.004910Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle 0$"
      ],
      "text/plain": [
       "0"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(r_P_S + r_S_Q).dt(B)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "df9fdcc2",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.007055Z",
     "iopub.status.busy": "2024-08-12T10:05:51.006903Z",
     "iopub.status.idle": "2024-08-12T10:05:51.024268Z",
     "shell.execute_reply": "2024-08-12T10:05:51.023868Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y + \\left(- c - \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_x + (- w \\cos{\\left(\\beta \\right)} \\dot{\\alpha} - \\left(- c - \\frac{l}{2}\\right) \\dot{\\beta})\\hat{b}_y + w \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z$"
      ],
      "text/plain": [
       "           ⎛     l⎞                ⎛              ⎛     l⎞  ⎞\n",
       "-d⋅α̇ a_y + ⎜-c - ─⎟⋅sin(β)⋅α̇ b_x + ⎜-w⋅cos(β)⋅α̇ - ⎜-c - ─⎟⋅β̇⎟ b_y + w⋅sin(\n",
       "           ⎝     2⎠                ⎝              ⎝     2⎠  ⎠\n",
       "\n",
       "\n",
       "β)⋅α̇ b_z\n"
      ]
     },
     "execution_count": 10,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "me.cross(B.ang_vel_in(N), r_P_S + r_S_Q)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "id": "8cbc0c76",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.025864Z",
     "iopub.status.busy": "2024-08-12T10:05:51.025715Z",
     "iopub.status.idle": "2024-08-12T10:05:51.038905Z",
     "shell.execute_reply": "2024-08-12T10:05:51.038530Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y + \\left(- c - \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_x + (- w \\cos{\\left(\\beta \\right)} \\dot{\\alpha} - \\left(- c - \\frac{l}{2}\\right) \\dot{\\beta})\\hat{b}_y + w \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z$"
      ],
      "text/plain": [
       "           ⎛     l⎞                ⎛              ⎛     l⎞  ⎞\n",
       "-d⋅α̇ a_y + ⎜-c - ─⎟⋅sin(β)⋅α̇ b_x + ⎜-w⋅cos(β)⋅α̇ - ⎜-c - ─⎟⋅β̇⎟ b_y + w⋅sin(\n",
       "           ⎝     2⎠                ⎝              ⎝     2⎠  ⎠\n",
       "\n",
       "\n",
       "β)⋅α̇ b_z\n"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "N_v_Q = (r_P_S + r_S_Q).dt(B) + me.cross(B.ang_vel_in(N), r_P_S + r_S_Q)\n",
    "N_v_Q"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "id": "8bef7868",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.040448Z",
     "iopub.status.busy": "2024-08-12T10:05:51.040295Z",
     "iopub.status.idle": "2024-08-12T10:05:51.044526Z",
     "shell.execute_reply": "2024-08-12T10:05:51.044115Z"
    }
   },
   "outputs": [],
   "source": [
    "O = me.Point('O')\n",
    "P = me.Point('P')\n",
    "S = me.Point('S')\n",
    "Q = me.Point('Q')\n",
    "\n",
    "P.set_pos(O, h*N.z)\n",
    "S.set_pos(P, -d*A.x)\n",
    "Q.set_pos(S, -w*B.x - (c + l/2)*B.z)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "id": "c7e73818",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.046502Z",
     "iopub.status.busy": "2024-08-12T10:05:51.046058Z",
     "iopub.status.idle": "2024-08-12T10:05:51.050750Z",
     "shell.execute_reply": "2024-08-12T10:05:51.050337Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  w\\hat{b}_x + (- c - \\frac{l}{2})\\hat{b}_z -  d\\hat{a}_x + h\\hat{n}_z$"
      ],
      "text/plain": [
       "         ⎛     l⎞\n",
       "-w b_x + ⎜-c - ─⎟ b_z + -d a_x + h n_z\n",
       "         ⎝     2⎠"
      ]
     },
     "execution_count": 13,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "Q.pos_from(O)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "id": "45800f79",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.052306Z",
     "iopub.status.busy": "2024-08-12T10:05:51.052159Z",
     "iopub.status.idle": "2024-08-12T10:05:51.054512Z",
     "shell.execute_reply": "2024-08-12T10:05:51.054106Z"
    }
   },
   "outputs": [],
   "source": [
    "O.set_vel(N, 0)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "id": "488ecfc8",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.055997Z",
     "iopub.status.busy": "2024-08-12T10:05:51.055852Z",
     "iopub.status.idle": "2024-08-12T10:05:51.070600Z",
     "shell.execute_reply": "2024-08-12T10:05:51.070203Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle \\left(- c - \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_x + (- w \\cos{\\left(\\beta \\right)} \\dot{\\alpha} - \\left(- c - \\frac{l}{2}\\right) \\dot{\\beta})\\hat{b}_y + w \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "⎛     l⎞                ⎛              ⎛     l⎞  ⎞\n",
       "⎜-c - ─⎟⋅sin(β)⋅α̇ b_x + ⎜-w⋅cos(β)⋅α̇ - ⎜-c - ─⎟⋅β̇⎟ b_y + w⋅sin(β)⋅α̇ b_z +\n",
       "⎝     2⎠                ⎝              ⎝     2⎠  ⎠\n",
       "\n",
       "\n",
       "-d⋅α̇ a_y\n"
      ]
     },
     "execution_count": 15,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "Q.vel(N)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "id": "87e64204",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.072397Z",
     "iopub.status.busy": "2024-08-12T10:05:51.072071Z",
     "iopub.status.idle": "2024-08-12T10:05:51.080148Z",
     "shell.execute_reply": "2024-08-12T10:05:51.079774Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle c \\dot{\\beta}\\hat{b}_y$"
      ],
      "text/plain": [
       "c⋅β̇ b_y"
      ]
     },
     "execution_count": 16,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "Bc = me.Point('B_c')\n",
    "Bc.set_pos(S, -c*B.z - w/2*A.x)\n",
    "me.cross(B.ang_vel_in(A), Bc.pos_from(S))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "id": "eec1c1ae",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.081755Z",
     "iopub.status.busy": "2024-08-12T10:05:51.081591Z",
     "iopub.status.idle": "2024-08-12T10:05:51.084110Z",
     "shell.execute_reply": "2024-08-12T10:05:51.083696Z"
    }
   },
   "outputs": [],
   "source": [
    "N_v_P = 0*N.z"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "id": "9ddc7562",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.085718Z",
     "iopub.status.busy": "2024-08-12T10:05:51.085558Z",
     "iopub.status.idle": "2024-08-12T10:05:51.090900Z",
     "shell.execute_reply": "2024-08-12T10:05:51.090510Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "-d⋅α̇ a_y"
      ]
     },
     "execution_count": 18,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "N_v_S = N_v_P +  me.cross(A.ang_vel_in(N), S.pos_from(P))\n",
    "N_v_S"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "id": "8cd4644b",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.092621Z",
     "iopub.status.busy": "2024-08-12T10:05:51.092318Z",
     "iopub.status.idle": "2024-08-12T10:05:51.097874Z",
     "shell.execute_reply": "2024-08-12T10:05:51.097480Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "-d⋅α̇ a_y"
      ]
     },
     "execution_count": 19,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "P.set_vel(N, 0)\n",
    "S.v2pt_theory(P, N, A)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "id": "98aa7f7e",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.099614Z",
     "iopub.status.busy": "2024-08-12T10:05:51.099251Z",
     "iopub.status.idle": "2024-08-12T10:05:51.103250Z",
     "shell.execute_reply": "2024-08-12T10:05:51.102752Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "-d⋅α̇ a_y"
      ]
     },
     "execution_count": 20,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "S.vel(N)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "id": "3d3657e9",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.105001Z",
     "iopub.status.busy": "2024-08-12T10:05:51.104715Z",
     "iopub.status.idle": "2024-08-12T10:05:51.114446Z",
     "shell.execute_reply": "2024-08-12T10:05:51.114058Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y + \\left(- c - \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_x + (- w \\cos{\\left(\\beta \\right)} \\dot{\\alpha} - \\left(- c - \\frac{l}{2}\\right) \\dot{\\beta})\\hat{b}_y + w \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z$"
      ],
      "text/plain": [
       "           ⎛     l⎞                ⎛              ⎛     l⎞  ⎞\n",
       "-d⋅α̇ a_y + ⎜-c - ─⎟⋅sin(β)⋅α̇ b_x + ⎜-w⋅cos(β)⋅α̇ - ⎜-c - ─⎟⋅β̇⎟ b_y + w⋅sin(\n",
       "           ⎝     2⎠                ⎝              ⎝     2⎠  ⎠\n",
       "\n",
       "\n",
       "β)⋅α̇ b_z\n"
      ]
     },
     "execution_count": 21,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "N_v_Q = N_v_S +  me.cross(B.ang_vel_in(N), Q.pos_from(S))\n",
    "N_v_Q"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "id": "91b39451",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.116419Z",
     "iopub.status.busy": "2024-08-12T10:05:51.115922Z",
     "iopub.status.idle": "2024-08-12T10:05:51.125574Z",
     "shell.execute_reply": "2024-08-12T10:05:51.125217Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y + \\left(- c - \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_x + (- w \\cos{\\left(\\beta \\right)} \\dot{\\alpha} - \\left(- c - \\frac{l}{2}\\right) \\dot{\\beta})\\hat{b}_y + w \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z$"
      ],
      "text/plain": [
       "           ⎛     l⎞                ⎛              ⎛     l⎞  ⎞\n",
       "-d⋅α̇ a_y + ⎜-c - ─⎟⋅sin(β)⋅α̇ b_x + ⎜-w⋅cos(β)⋅α̇ - ⎜-c - ─⎟⋅β̇⎟ b_y + w⋅sin(\n",
       "           ⎝     2⎠                ⎝              ⎝     2⎠  ⎠\n",
       "\n",
       "\n",
       "β)⋅α̇ b_z\n"
      ]
     },
     "execution_count": 22,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "Q.v2pt_theory(S, N, B)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "id": "e0403adb",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.127187Z",
     "iopub.status.busy": "2024-08-12T10:05:51.127020Z",
     "iopub.status.idle": "2024-08-12T10:05:51.137960Z",
     "shell.execute_reply": "2024-08-12T10:05:51.137456Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle (- d \\dot{\\alpha} - \\frac{w \\dot{\\alpha}}{2})\\hat{a}_y -  c \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_x + c \\dot{\\beta}\\hat{b}_y$"
      ],
      "text/plain": [
       "⎛       w⋅α̇⎞\n",
       "⎜-d⋅α̇ - ───⎟ a_y + -c⋅sin(β)⋅α̇ b_x + c⋅β̇ b_y\n",
       "⎝        2 ⎠"
      ]
     },
     "execution_count": 23,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "Bc = me.Point('B_c')\n",
    "Bc.set_pos(S, -c*B.z - w/2*A.x)\n",
    "Bc.v2pt_theory(S, N, B)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 24,
   "id": "73a6e1cc",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.139690Z",
     "iopub.status.busy": "2024-08-12T10:05:51.139438Z",
     "iopub.status.idle": "2024-08-12T10:05:51.143279Z",
     "shell.execute_reply": "2024-08-12T10:05:51.142783Z"
    }
   },
   "outputs": [],
   "source": [
    "s = me.dynamicsymbols('s')\n",
    "t = me.dynamicsymbols._t\n",
    "\n",
    "R = me.Point('R')\n",
    "R.set_pos(Q, l*B.z + s*B.x)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 25,
   "id": "e610f22c",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.145056Z",
     "iopub.status.busy": "2024-08-12T10:05:51.144744Z",
     "iopub.status.idle": "2024-08-12T10:05:51.148970Z",
     "shell.execute_reply": "2024-08-12T10:05:51.148598Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle \\dot{s}\\hat{b}_x$"
      ],
      "text/plain": [
       "ṡ b_x"
      ]
     },
     "execution_count": 25,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "B_v_R = s.diff(t)*B.x\n",
    "B_v_R"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 26,
   "id": "8b25afa7",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.150552Z",
     "iopub.status.busy": "2024-08-12T10:05:51.150400Z",
     "iopub.status.idle": "2024-08-12T10:05:51.155397Z",
     "shell.execute_reply": "2024-08-12T10:05:51.154909Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle (- w + s)\\hat{b}_x + (- c + \\frac{l}{2})\\hat{b}_z$"
      ],
      "text/plain": [
       "               ⎛     l⎞\n",
       "(-w + s) b_x + ⎜-c + ─⎟ b_z\n",
       "               ⎝     2⎠"
      ]
     },
     "execution_count": 26,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "r_S_R = R.pos_from(S)\n",
    "r_S_R"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 27,
   "id": "42d32ac3",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.157255Z",
     "iopub.status.busy": "2024-08-12T10:05:51.156949Z",
     "iopub.status.idle": "2024-08-12T10:05:51.170844Z",
     "shell.execute_reply": "2024-08-12T10:05:51.170352Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\dot{\\alpha}\\hat{a}_y + \\left(- c + \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_x + (- \\left(- c + \\frac{l}{2}\\right) \\dot{\\beta} + \\left(- w + s\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha})\\hat{b}_y -  \\left(- w + s\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z$"
      ],
      "text/plain": [
       "           ⎛     l⎞                ⎛  ⎛     l⎞                      ⎞\n",
       "-d⋅α̇ a_y + ⎜-c + ─⎟⋅sin(β)⋅α̇ b_x + ⎜- ⎜-c + ─⎟⋅β̇ + (-w + s)⋅cos(β)⋅α̇⎟ b_y\n",
       "           ⎝     2⎠                ⎝  ⎝     2⎠                      ⎠\n",
       "\n",
       "\n",
       "+ -(-w + s)⋅sin(β)⋅α̇ b_z\n"
      ]
     },
     "execution_count": 27,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "N_v_T = N_v_S + me.cross(B.ang_vel_in(N), r_S_R)\n",
    "N_v_T"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 28,
   "id": "e218aeab",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.172848Z",
     "iopub.status.busy": "2024-08-12T10:05:51.172436Z",
     "iopub.status.idle": "2024-08-12T10:05:51.181249Z",
     "shell.execute_reply": "2024-08-12T10:05:51.180758Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle (\\left(- c + \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha} + \\dot{s})\\hat{b}_x + (- \\left(- c + \\frac{l}{2}\\right) \\dot{\\beta} + \\left(- w + s\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha})\\hat{b}_y -  \\left(- w + s\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "⎛⎛     l⎞             ⎞       ⎛  ⎛     l⎞                      ⎞\n",
       "⎜⎜-c + ─⎟⋅sin(β)⋅α̇ + ṡ⎟ b_x + ⎜- ⎜-c + ─⎟⋅β̇ + (-w + s)⋅cos(β)⋅α̇⎟ b_y + -(-\n",
       "⎝⎝     2⎠             ⎠       ⎝  ⎝     2⎠                      ⎠\n",
       "\n",
       "\n",
       "w + s)⋅sin(β)⋅α̇ b_z + -d⋅α̇ a_y\n"
      ]
     },
     "execution_count": 28,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "N_v_R = B_v_R + N_v_T\n",
    "N_v_R"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 29,
   "id": "0ecd727d",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.183002Z",
     "iopub.status.busy": "2024-08-12T10:05:51.182847Z",
     "iopub.status.idle": "2024-08-12T10:05:51.200850Z",
     "shell.execute_reply": "2024-08-12T10:05:51.200478Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle (\\left(- c + \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha} + \\dot{s})\\hat{b}_x + (- \\left(- c + \\frac{l}{2}\\right) \\dot{\\beta} + \\left(- w + s\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha})\\hat{b}_y -  \\left(- w + s\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha}\\hat{b}_z -  d \\dot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "⎛⎛     l⎞             ⎞       ⎛  ⎛     l⎞                      ⎞\n",
       "⎜⎜-c + ─⎟⋅sin(β)⋅α̇ + ṡ⎟ b_x + ⎜- ⎜-c + ─⎟⋅β̇ + (-w + s)⋅cos(β)⋅α̇⎟ b_y + -(-\n",
       "⎝⎝     2⎠             ⎠       ⎝  ⎝     2⎠                      ⎠\n",
       "\n",
       "\n",
       "w + s)⋅sin(β)⋅α̇ b_z + -d⋅α̇ a_y\n"
      ]
     },
     "execution_count": 29,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "S.set_vel(B, 0)\n",
    "R.v1pt_theory(S, N, B)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 30,
   "id": "4d00cb2d",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.202728Z",
     "iopub.status.busy": "2024-08-12T10:05:51.202317Z",
     "iopub.status.idle": "2024-08-12T10:05:51.211232Z",
     "shell.execute_reply": "2024-08-12T10:05:51.210816Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle d \\dot{\\alpha}^{2}\\hat{a}_x -  d \\ddot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "   2\n",
       "d⋅α̇  a_x + -d⋅α̈ a_y"
      ]
     },
     "execution_count": 30,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "S.acc(N)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 31,
   "id": "9237cad5",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.212802Z",
     "iopub.status.busy": "2024-08-12T10:05:51.212664Z",
     "iopub.status.idle": "2024-08-12T10:05:51.219845Z",
     "shell.execute_reply": "2024-08-12T10:05:51.219454Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle -  d \\ddot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "-d⋅α̈ a_y"
      ]
     },
     "execution_count": 31,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "me.cross(A.ang_acc_in(N), S.pos_from(P))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 32,
   "id": "a7afe111",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.221406Z",
     "iopub.status.busy": "2024-08-12T10:05:51.221269Z",
     "iopub.status.idle": "2024-08-12T10:05:51.227975Z",
     "shell.execute_reply": "2024-08-12T10:05:51.227493Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle d \\dot{\\alpha}^{2}\\hat{a}_x$"
      ],
      "text/plain": [
       "   2\n",
       "d⋅α̇  a_x"
      ]
     },
     "execution_count": 32,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "me.cross(A.ang_vel_in(N), me.cross(A.ang_vel_in(N), S.pos_from(P)))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 33,
   "id": "d6bdbb8f",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.229854Z",
     "iopub.status.busy": "2024-08-12T10:05:51.229398Z",
     "iopub.status.idle": "2024-08-12T10:05:51.238941Z",
     "shell.execute_reply": "2024-08-12T10:05:51.238563Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle d \\dot{\\alpha}^{2}\\hat{a}_x -  d \\ddot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "   2\n",
       "d⋅α̇  a_x + -d⋅α̈ a_y"
      ]
     },
     "execution_count": 33,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "S.a2pt_theory(P, N, A)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 34,
   "id": "e23ae386",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.240613Z",
     "iopub.status.busy": "2024-08-12T10:05:51.240463Z",
     "iopub.status.idle": "2024-08-12T10:05:51.277716Z",
     "shell.execute_reply": "2024-08-12T10:05:51.277318Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle d \\dot{\\alpha}^{2}\\hat{a}_x -  d \\ddot{\\alpha}\\hat{a}_y + (w \\sin^{2}{\\left(\\beta \\right)} \\dot{\\alpha}^{2} + \\left(- c - \\frac{l}{2}\\right) \\left(\\sin{\\left(\\beta \\right)} \\ddot{\\alpha} + \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta}\\right) - \\left(- w \\cos{\\left(\\beta \\right)} \\dot{\\alpha} - \\left(- c - \\frac{l}{2}\\right) \\dot{\\beta}\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha})\\hat{b}_x + (- w \\left(- \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta} + \\cos{\\left(\\beta \\right)} \\ddot{\\alpha}\\right) - w \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta} + \\left(- c - \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\cos{\\left(\\beta \\right)} \\dot{\\alpha}^{2} - \\left(- c - \\frac{l}{2}\\right) \\ddot{\\beta})\\hat{b}_y + (w \\left(\\sin{\\left(\\beta \\right)} \\ddot{\\alpha} + \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta}\\right) - \\left(- c - \\frac{l}{2}\\right) \\sin^{2}{\\left(\\beta \\right)} \\dot{\\alpha}^{2} + \\left(- w \\cos{\\left(\\beta \\right)} \\dot{\\alpha} - \\left(- c - \\frac{l}{2}\\right) \\dot{\\beta}\\right) \\dot{\\beta})\\hat{b}_z$"
      ],
      "text/plain": [
       "   2                  ⎛     2     2   ⎛     l⎞                           ⎛\n",
       "d⋅α̇  a_x + -d⋅α̈ a_y + ⎜w⋅sin (β)⋅α̇  + ⎜-c - ─⎟⋅(sin(β)⋅α̈ + cos(β)⋅α̇⋅β̇) -\n",
       "                      ⎝               ⎝     2⎠                           ⎝\n",
       "\n",
       "          ⎛     l⎞  ⎞         ⎞       ⎛\n",
       " ⎜-w⋅cos(β)⋅α̇ - ⎜-c - ─⎟⋅β̇⎟⋅cos(β)⋅α̇⎟ b_x + ⎜-w⋅(-sin(β)⋅α̇⋅β̇ + cos(β)⋅α̈)\n",
       "          ⎝     2⎠  ⎠         ⎠       ⎝\n",
       "\n",
       "      ⎛     l⎞                2   ⎛     l⎞  ⎞       ⎛\n",
       " - w⋅sin(β)⋅α̇⋅β̇ + ⎜-c - ─⎟⋅sin(β)⋅cos(β)⋅α̇  - ⎜-c - ─⎟⋅β̈⎟ b_y + ⎜w⋅(sin(β)\n",
       "      ⎝     2⎠                    ⎝     2⎠  ⎠       ⎝\n",
       "\n",
       "   ⎛     l⎞    2     2   ⎛              ⎛     l⎞  ⎞  ⎞\n",
       "⋅α̈ + cos(β)⋅α̇⋅β̇) - ⎜-c - ─⎟⋅sin (β)⋅α̇  + ⎜-w⋅cos(β)⋅α̇ - ⎜-c - ─⎟⋅β̇⎟⋅β̇⎟\n",
       "   ⎝     2⎠              ⎝              ⎝     2⎠  ⎠  ⎠"
      ]
     },
     "execution_count": 34,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "Q.a2pt_theory(S, N, B)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 35,
   "id": "d0e032b2",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.279308Z",
     "iopub.status.busy": "2024-08-12T10:05:51.279158Z",
     "iopub.status.idle": "2024-08-12T10:05:51.284073Z",
     "shell.execute_reply": "2024-08-12T10:05:51.283583Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle \\ddot{s}\\hat{b}_x$"
      ],
      "text/plain": [
       "s̈ b_x"
      ]
     },
     "execution_count": 35,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "B_a_R = R.acc(B)\n",
    "B_a_R"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 36,
   "id": "103cd398",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.285733Z",
     "iopub.status.busy": "2024-08-12T10:05:51.285595Z",
     "iopub.status.idle": "2024-08-12T10:05:51.321555Z",
     "shell.execute_reply": "2024-08-12T10:05:51.321117Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle d \\dot{\\alpha}^{2}\\hat{a}_x -  d \\ddot{\\alpha}\\hat{a}_y + (\\left(- c + \\frac{l}{2}\\right) \\left(\\sin{\\left(\\beta \\right)} \\ddot{\\alpha} + \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta}\\right) - \\left(- w + s\\right) \\sin^{2}{\\left(\\beta \\right)} \\dot{\\alpha}^{2} - \\left(- \\left(- c + \\frac{l}{2}\\right) \\dot{\\beta} + \\left(- w + s\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha}\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha})\\hat{b}_x + (\\left(- c + \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\cos{\\left(\\beta \\right)} \\dot{\\alpha}^{2} - \\left(- c + \\frac{l}{2}\\right) \\ddot{\\beta} + \\left(- w + s\\right) \\left(- \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta} + \\cos{\\left(\\beta \\right)} \\ddot{\\alpha}\\right) + \\left(- w + s\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta})\\hat{b}_y + (- \\left(- c + \\frac{l}{2}\\right) \\sin^{2}{\\left(\\beta \\right)} \\dot{\\alpha}^{2} - \\left(- w + s\\right) \\left(\\sin{\\left(\\beta \\right)} \\ddot{\\alpha} + \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta}\\right) + \\left(- \\left(- c + \\frac{l}{2}\\right) \\dot{\\beta} + \\left(- w + s\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha}\\right) \\dot{\\beta})\\hat{b}_z$"
      ],
      "text/plain": [
       "   2                  ⎛⎛     l⎞                                       2     2\n",
       "d⋅α̇  a_x + -d⋅α̈ a_y + ⎜⎜-c + ─⎟⋅(sin(β)⋅α̈ + cos(β)⋅α̇⋅β̇) - (-w + s)⋅sin (β\n",
       "                      ⎝⎝     2⎠\n",
       "\n",
       "  ⎛  ⎛     l⎞                      ⎞         ⎞       ⎛⎛     l⎞\n",
       ")⋅α̇  - ⎜- ⎜-c + ─⎟⋅β̇ + (-w + s)⋅cos(β)⋅α̇⎟⋅cos(β)⋅α̇⎟ b_x + ⎜⎜-c + ─⎟⋅sin(β)\n",
       "  ⎝  ⎝     2⎠                      ⎠         ⎠       ⎝⎝     2⎠\n",
       "\n",
       "2   ⎛     l⎞                                                            ⎞\n",
       "⋅cos(β)⋅α̇  - ⎜-c + ─⎟⋅β̈ + (-w + s)⋅(-sin(β)⋅α̇⋅β̇ + cos(β)⋅α̈) + (-w + s)⋅si\n",
       "    ⎝     2⎠                                                            ⎠\n",
       "\n",
       "  ⎛  ⎛     l⎞    2     2                                      ⎛  ⎛     l⎞\n",
       "n(β)⋅α̇⋅β̇⎟ b_y + ⎜- ⎜-c + ─⎟⋅sin (β)⋅α̇  - (-w + s)⋅(sin(β)⋅α̈ + cos(β)⋅α̇⋅β̇\n",
       "  ⎝  ⎝     2⎠                                                 ⎝  ⎝     2⎠\n",
       "\n",
       "                 ⎞  ⎞\n",
       ") + ⎜- ⎜-c + ─⎟⋅β̇ + (-w + s)⋅cos(β)⋅α̇⎟⋅β̇⎟ b_z\n",
       "                 ⎠  ⎠"
      ]
     },
     "execution_count": 36,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "N_a_T = R.a2pt_theory(S, N, B)\n",
    "N_a_T"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 37,
   "id": "5ec71867",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.323297Z",
     "iopub.status.busy": "2024-08-12T10:05:51.323116Z",
     "iopub.status.idle": "2024-08-12T10:05:51.331539Z",
     "shell.execute_reply": "2024-08-12T10:05:51.331043Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle 2 \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{s}\\hat{b}_y -  2 \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{s}\\hat{b}_z$"
      ],
      "text/plain": [
       "2⋅cos(β)⋅α̇⋅ṡ b_y + -2⋅sin(β)⋅α̇⋅ṡ b_z"
      ]
     },
     "execution_count": 37,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "2*me.cross(B.ang_vel_in(N), R.vel(B))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 38,
   "id": "6d472663",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-08-12T10:05:51.333373Z",
     "iopub.status.busy": "2024-08-12T10:05:51.333050Z",
     "iopub.status.idle": "2024-08-12T10:05:51.370941Z",
     "shell.execute_reply": "2024-08-12T10:05:51.370423Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/latex": [
       "$\\displaystyle (\\left(- c + \\frac{l}{2}\\right) \\left(\\sin{\\left(\\beta \\right)} \\ddot{\\alpha} + \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta}\\right) - \\left(- w + s\\right) \\sin^{2}{\\left(\\beta \\right)} \\dot{\\alpha}^{2} - \\left(- \\left(- c + \\frac{l}{2}\\right) \\dot{\\beta} + \\left(- w + s\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha}\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha} + \\ddot{s})\\hat{b}_x + (\\left(- c + \\frac{l}{2}\\right) \\sin{\\left(\\beta \\right)} \\cos{\\left(\\beta \\right)} \\dot{\\alpha}^{2} - \\left(- c + \\frac{l}{2}\\right) \\ddot{\\beta} + \\left(- w + s\\right) \\left(- \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta} + \\cos{\\left(\\beta \\right)} \\ddot{\\alpha}\\right) + \\left(- w + s\\right) \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta} + 2 \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{s})\\hat{b}_y + (- \\left(- c + \\frac{l}{2}\\right) \\sin^{2}{\\left(\\beta \\right)} \\dot{\\alpha}^{2} - \\left(- w + s\\right) \\left(\\sin{\\left(\\beta \\right)} \\ddot{\\alpha} + \\cos{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{\\beta}\\right) + \\left(- \\left(- c + \\frac{l}{2}\\right) \\dot{\\beta} + \\left(- w + s\\right) \\cos{\\left(\\beta \\right)} \\dot{\\alpha}\\right) \\dot{\\beta} - 2 \\sin{\\left(\\beta \\right)} \\dot{\\alpha} \\dot{s})\\hat{b}_z + d \\dot{\\alpha}^{2}\\hat{a}_x -  d \\ddot{\\alpha}\\hat{a}_y$"
      ],
      "text/plain": [
       "⎛⎛     l⎞                                       2     2   ⎛  ⎛     l⎞\n",
       "⎜⎜-c + ─⎟⋅(sin(β)⋅α̈ + cos(β)⋅α̇⋅β̇) - (-w + s)⋅sin (β)⋅α̇  - ⎜- ⎜-c + ─⎟⋅β̇ +\n",
       "⎝⎝     2⎠                                                 ⎝  ⎝     2⎠\n",
       "\n",
       "             ⎞             ⎞       ⎛⎛     l⎞                2   ⎛     l⎞\n",
       " (-w + s)⋅cos(β)⋅α̇⎟⋅cos(β)⋅α̇ + s̈⎟ b_x + ⎜⎜-c + ─⎟⋅sin(β)⋅cos(β)⋅α̇  - ⎜-c +\n",
       "             ⎠             ⎠       ⎝⎝     2⎠                    ⎝     2⎠\n",
       "\n",
       "                                                                     ⎞       ⎛\n",
       " ─⎟⋅β̈ + (-w + s)⋅(-sin(β)⋅α̇⋅β̇ + cos(β)⋅α̈) + (-w + s)⋅sin(β)⋅α̇⋅β̇ + 2⋅cos(\n",
       "                                                                     ⎠       ⎝\n",
       "\n",
       "  ⎛     l⎞    2     2                                      ⎛  ⎛     l⎞\n",
       "β)⋅α̇⋅ṡ⎟ b_y + ⎜- ⎜-c + ─⎟⋅sin (β)⋅α̇  - (-w + s)⋅(sin(β)⋅α̈ + cos(β)⋅α̇⋅β̇)\n",
       "  ⎝     2⎠                                                 ⎝  ⎝     2⎠\n",
       "\n",
       "              ⎞                 ⎞          2\n",
       "+ ⎜- ⎜-c + ─⎟⋅β̇ + (-w + s)⋅cos(β)⋅α̇⎟⋅β̇ - 2⋅sin(β)⋅α̇⋅ṡ⎟ b_z + d⋅α̇  a_x +\n",
       "              ⎠                 ⎠"
      ]
     },
     "execution_count": 38,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "R.a1pt_theory(S, N, B)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.9"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}